# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reports_report_facets_response import ReportsReportFacetsResponse

class TestReportsReportFacetsResponse(unittest.TestCase):
    """ReportsReportFacetsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportsReportFacetsResponse:
        """Test ReportsReportFacetsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportsReportFacetsResponse`
        """
        model = ReportsReportFacetsResponse()
        if include_optional:
            return ReportsReportFacetsResponse(
                concepts = [
                    neurograph.v1.models.reports/facet_item.reports.FacetItem(
                        count = 56, 
                        value = '', )
                    ],
                error = '',
                themes = [
                    neurograph.v1.models.reports/facet_item.reports.FacetItem(
                        count = 56, 
                        value = '', )
                    ],
                topics = [
                    neurograph.v1.models.reports/facet_item.reports.FacetItem(
                        count = 56, 
                        value = '', )
                    ],
                types = [
                    neurograph.v1.models.reports/facet_item.reports.FacetItem(
                        count = 56, 
                        value = '', )
                    ]
            )
        else:
            return ReportsReportFacetsResponse(
        )
        """

    def testReportsReportFacetsResponse(self):
        """Test ReportsReportFacetsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
