# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class OpportunitiesOpportunityResponse(BaseModel):
    """
    OpportunitiesOpportunityResponse
    """ # noqa: E501
    action_description: Optional[StrictStr] = None
    category: Optional[StrictStr] = None
    client_id: Optional[StrictStr] = None
    comparison_context: Optional[StrictStr] = None
    comparison_stat: Optional[StrictStr] = None
    comparison_type: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    display_order: Optional[StrictInt] = None
    effort_level: Optional[StrictStr] = None
    error: Optional[StrictStr] = None
    id: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    organization_id: Optional[StrictStr] = None
    priority_tier: Optional[StrictStr] = None
    roi_metric: Optional[StrictStr] = None
    roi_progress: Optional[StrictInt] = None
    roi_value: Optional[StrictStr] = None
    status: Optional[StrictStr] = None
    subtitle: Optional[StrictStr] = None
    ts_created: Optional[StrictStr] = None
    ts_updated: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["action_description", "category", "client_id", "comparison_context", "comparison_stat", "comparison_type", "description", "display_order", "effort_level", "error", "id", "name", "organization_id", "priority_tier", "roi_metric", "roi_progress", "roi_value", "status", "subtitle", "ts_created", "ts_updated"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of OpportunitiesOpportunityResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of OpportunitiesOpportunityResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "action_description": obj.get("action_description"),
            "category": obj.get("category"),
            "client_id": obj.get("client_id"),
            "comparison_context": obj.get("comparison_context"),
            "comparison_stat": obj.get("comparison_stat"),
            "comparison_type": obj.get("comparison_type"),
            "description": obj.get("description"),
            "display_order": obj.get("display_order"),
            "effort_level": obj.get("effort_level"),
            "error": obj.get("error"),
            "id": obj.get("id"),
            "name": obj.get("name"),
            "organization_id": obj.get("organization_id"),
            "priority_tier": obj.get("priority_tier"),
            "roi_metric": obj.get("roi_metric"),
            "roi_progress": obj.get("roi_progress"),
            "roi_value": obj.get("roi_value"),
            "status": obj.get("status"),
            "subtitle": obj.get("subtitle"),
            "ts_created": obj.get("ts_created"),
            "ts_updated": obj.get("ts_updated")
        })
        return _obj


