# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.pixel_client_pixel_totals import PixelClientPixelTotals

class TestPixelClientPixelTotals(unittest.TestCase):
    """PixelClientPixelTotals unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PixelClientPixelTotals:
        """Test PixelClientPixelTotals
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PixelClientPixelTotals`
        """
        model = PixelClientPixelTotals()
        if include_optional:
            return PixelClientPixelTotals(
                avg_enrichment_rate_pct = 1.337,
                avg_match_rate_pct = 1.337,
                temporal_match_pct = 1.337,
                temporal_match_total = 56,
                total_enriched = 56,
                total_estimated_cost = 1.337,
                total_matched = 56,
                total_pageviews = 56,
                total_sessions = 56,
                total_visitors = 56,
                vendor_match_pct = 1.337,
                vendor_match_total = 56
            )
        else:
            return PixelClientPixelTotals(
        )
        """

    def testPixelClientPixelTotals(self):
        """Test PixelClientPixelTotals"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
