# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_model_job_summary import ReportingModelJobSummary

class TestReportingModelJobSummary(unittest.TestCase):
    """ReportingModelJobSummary unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingModelJobSummary:
        """Test ReportingModelJobSummary
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingModelJobSummary`
        """
        model = ReportingModelJobSummary()
        if include_optional:
            return ReportingModelJobSummary(
                active_build = 56,
                assignment_date = '',
                build_timestamp = '',
                client_id = '',
                client_name = '',
                job_id = '',
                model_type = '',
                model_version = '',
                org_name = '',
                prediction_count = 56
            )
        else:
            return ReportingModelJobSummary(
        )
        """

    def testReportingModelJobSummary(self):
        """Test ReportingModelJobSummary"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
