# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.client_organization_brand import ClientOrganizationBrand

class TestClientOrganizationBrand(unittest.TestCase):
    """ClientOrganizationBrand unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ClientOrganizationBrand:
        """Test ClientOrganizationBrand
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ClientOrganizationBrand`
        """
        model = ClientOrganizationBrand()
        if include_optional:
            return ClientOrganizationBrand(
                background_img_url = '',
                color1 = '',
                color2 = '',
                color3 = '',
                color4 = '',
                color5 = '',
                id = '',
                logo_img_url = '',
                primary_color = '',
                secondary_color = '',
                tertiary_color = ''
            )
        else:
            return ClientOrganizationBrand(
        )
        """

    def testClientOrganizationBrand(self):
        """Test ClientOrganizationBrand"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
