# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.knowledge_enrichment_artifact_update_status_request import KnowledgeEnrichmentArtifactUpdateStatusRequest

class TestKnowledgeEnrichmentArtifactUpdateStatusRequest(unittest.TestCase):
    """KnowledgeEnrichmentArtifactUpdateStatusRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> KnowledgeEnrichmentArtifactUpdateStatusRequest:
        """Test KnowledgeEnrichmentArtifactUpdateStatusRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `KnowledgeEnrichmentArtifactUpdateStatusRequest`
        """
        model = KnowledgeEnrichmentArtifactUpdateStatusRequest()
        if include_optional:
            return KnowledgeEnrichmentArtifactUpdateStatusRequest(
                agent_engine_run_id = '',
                attempt_count = 56,
                cloud_run_execution_id = '',
                completed_at = '',
                last_error = '',
                started_at = '',
                status = 'RUNNING'
            )
        else:
            return KnowledgeEnrichmentArtifactUpdateStatusRequest(
        )
        """

    def testKnowledgeEnrichmentArtifactUpdateStatusRequest(self):
        """Test KnowledgeEnrichmentArtifactUpdateStatusRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
