# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_customer_cycle_metrics import ReportingCustomerCycleMetrics

class TestReportingCustomerCycleMetrics(unittest.TestCase):
    """ReportingCustomerCycleMetrics unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingCustomerCycleMetrics:
        """Test ReportingCustomerCycleMetrics
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingCustomerCycleMetrics`
        """
        model = ReportingCustomerCycleMetrics()
        if include_optional:
            return ReportingCustomerCycleMetrics(
                count = 56,
                cycle_days = 56,
                display_value = '',
                median_days = 56,
                tiers = neurograph.v1.models.reporting/cycle_tiers.reporting.CycleTiers(
                    fast = 56, 
                    slow = 56, 
                    typical = 56, )
            )
        else:
            return ReportingCustomerCycleMetrics(
        )
        """

    def testReportingCustomerCycleMetrics(self):
        """Test ReportingCustomerCycleMetrics"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
