# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.opportunities_opportunity_create_request import OpportunitiesOpportunityCreateRequest

class TestOpportunitiesOpportunityCreateRequest(unittest.TestCase):
    """OpportunitiesOpportunityCreateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OpportunitiesOpportunityCreateRequest:
        """Test OpportunitiesOpportunityCreateRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OpportunitiesOpportunityCreateRequest`
        """
        model = OpportunitiesOpportunityCreateRequest()
        if include_optional:
            return OpportunitiesOpportunityCreateRequest(
                action_description = '',
                category = '',
                client_id = '',
                comparison_context = '',
                comparison_stat = '',
                comparison_type = '',
                description = '',
                display_order = 56,
                effort_level = '',
                name = '',
                organization_id = '',
                priority_tier = '',
                roi_metric = '',
                roi_progress = 56,
                roi_value = '',
                subtitle = ''
            )
        else:
            return OpportunitiesOpportunityCreateRequest(
        )
        """

    def testOpportunitiesOpportunityCreateRequest(self):
        """Test OpportunitiesOpportunityCreateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
